==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/WebFieldPipeArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFieldPipeArgsDescription } from "./WebFieldPipeArgsDescription";
/**
 * @hidden
 */
export let WebFieldPipeArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebFieldPipeArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebFieldPipeArgsDescriptionMetadata.a == null) {
                WebFieldPipeArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebFieldPipeArgsDescriptionMetadata.c(WebFieldPipeArgsDescriptionMetadata.a);
            }
            if (a.j(WebFieldPipeArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(WebFieldPipeArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:FieldPipeArgs");
            a.item("__packageNameWC", "String:grids");
            a.item("__isPlainObject", "Boolean");
            a.item("Format", "String");
            a.item("Timezone", "String");
            a.item("DigitsInfo", "String");
            a.item("CurrencyCode", "String");
            a.item("Display", "String");
            a.item("WeekStart", "Number:double");
        }
        static d(a) {
            WebFieldPipeArgsDescriptionMetadata.b(a);
            a.aa("WebFieldPipeArgs", () => new WebFieldPipeArgsDescription());
            a.z("WebFieldPipeArgs", WebFieldPipeArgsDescriptionMetadata.a);
        }
    }
    WebFieldPipeArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebFieldPipeArgsDescriptionMetadata, 'WebFieldPipeArgsDescriptionMetadata');
    WebFieldPipeArgsDescriptionMetadata.a = null;
    return WebFieldPipeArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebFieldPipeArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFieldPipeArgsDescription } from "./WebFieldPipeArgsDescription";
/**
 * @hidden
 */
export let WebFieldPipeArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebFieldPipeArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebFieldPipeArgsDescriptionMetadata.a == null) {
                WebFieldPipeArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebFieldPipeArgsDescriptionMetadata.c(WebFieldPipeArgsDescriptionMetadata.a);
            }
            if (a.k(WebFieldPipeArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebFieldPipeArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:FieldPipeArgs");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Format", "String");
            a.item("Timezone", "String");
            a.item("DigitsInfo", "String");
            a.item("CurrencyCode", "String");
            a.item("Display", "String");
            a.item("WeekStart", "Number:double");
        }
        static d(a) {
            WebFieldPipeArgsDescriptionMetadata.b(a);
            a.ac("WebFieldPipeArgs", () => new WebFieldPipeArgsDescription());
            a.ab("WebFieldPipeArgs", WebFieldPipeArgsDescriptionMetadata.a);
        }
    }
    WebFieldPipeArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebFieldPipeArgsDescriptionMetadata, 'WebFieldPipeArgsDescriptionMetadata');
    WebFieldPipeArgsDescriptionMetadata.a = null;
    return WebFieldPipeArgsDescriptionMetadata;
})();
